@@ -45,7 +45,7 @@ class QCticAPI:
             host (str): (Optional) URL of the API server (``http://localhost`` by default).
         """
 
-        self._defaults = {"Content-Type": "application/json"}
+        self._req_defaults = {"headers": {"Content-Type": "application/json"}}
         self._client = AsyncHTTPClient()
         self._host = host
         self._loop = None
@@ -54,7 +54,13 @@ class QCticAPI:
     def loop(self):
         """asyncio.AbstractEventLoop: The event loop used by the sync methods of this class."""
 
-        return self._loop if self._loop else asyncio.get_event_loop()
+        if self._loop:
+            return self._loop
+
+        try:
+            return asyncio.get_running_loop()
+        except (RuntimeError, AttributeError):
+            return asyncio.get_event_loop()
 
     @loop.setter
     def loop(self, val):
@@ -67,17 +73,15 @@ class QCticAPI:
         if not self.has_auth:
             raise Exception("Must authenticate first")
 
-        AsyncHTTPClient.configure(None, defaults=self._defaults)
-
         return self._client
 
     @property
     def has_auth(self):
         """bool: True if the authentication arguments are defined."""
 
-        token = self._defaults.get("headers", {}).get("Authorization")
-        user = self._defaults.get("auth_username")
-        passwd = self._defaults.get("auth_password")
+        token = self._req_defaults.get("headers", {}).get("Authorization")
+        user = self._req_defaults.get("auth_username")
+        passwd = self._req_defaults.get("auth_password")
 
         return token or (user and passwd)
 
@@ -85,9 +89,9 @@ class QCticAPI:
         return urljoin(self._host, part)
 
     def _clean_auth(self):
-        self._defaults.pop("auth_username", None)
-        self._defaults.pop("auth_password", None)
-        self._defaults.get("headers", {}).pop("Authorization", None)
+        self._req_defaults.pop("auth_username", None)
+        self._req_defaults.pop("auth_password", None)
+        self._req_defaults.get("headers", {}).pop("Authorization", None)
 
     def auth_token(self, token):
         """Update the HTTP client configuration to use *Bearer* authorization.
@@ -100,9 +104,9 @@ class QCticAPI:
 
         self._clean_auth()
 
-        self._defaults["headers"] = self._defaults.get("headers", {})
+        self._req_defaults["headers"] = self._req_defaults.get("headers", {})
 
-        self._defaults["headers"].update({
+        self._req_defaults["headers"].update({
             "Authorization": "Bearer {}".format(token)
         })
 
@@ -118,11 +122,16 @@ class QCticAPI:
 
         self._clean_auth()
 
-        self._defaults.update({
+        self._req_defaults.update({
             "auth_username": user,
             "auth_password": passwd
         })
 
+    def _request(self, **kwargs):
+        request_params = {**self._req_defaults}
+        request_params.update(kwargs)
+        return HTTPRequest(**request_params)
+
     async def get_job(self, job_id):
         """Retrieves a single Job from the API.
 
@@ -133,7 +142,7 @@ class QCticAPI:
             dict: Dict that conforms to the ``JobSchema`` schema.
         """
 
-        req = HTTPRequest(
+        req = self._request(
             url=self._build_url("/jobs/{}".format(job_id)),
             method="GET")
 
@@ -159,7 +168,7 @@ class QCticAPI:
 
         params = GetJobsQuerySchema().dump(kwargs)
 
-        req = HTTPRequest(
+        req = self._request(
             url=url_concat(self._build_url("/jobs"), params),
             method="GET")
 
@@ -175,7 +184,7 @@ class QCticAPI:
             dict: Dict that conforms to the ``BackendStatusSchema`` schema.
         """
 
-        req = HTTPRequest(
+        req = self._request(
             url=self._build_url("/status"),
             method="GET")
 
@@ -203,7 +212,7 @@ class QCticAPI:
 
         body = json_encode(JobSchema().dump(job_init))
 
-        req = HTTPRequest(
+        req = self._request(
             url=self._build_url("/jobs"),
             method="POST",
             body=body)
@@ -220,7 +229,7 @@ class QCticAPI:
 
         body = json_encode({"status": JobStatus.CANCELLED.name})
 
-        req = HTTPRequest(
+        req = self._request(
             url=self._build_url("/jobs/{}".format(job_id)),
             method="PUT",
             body=body)
